==> openshift-model-miscellaneous-5.12.4-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class L4RedirectRuleBuilder extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluentImpl<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleBuilder>{
  public L4RedirectRuleBuilder() {
    this(false);
  }
  public L4RedirectRuleBuilder(java.lang.Boolean validationEnabled) {
    this(new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule instance) {
    this(fluent, instance, false);
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestinationIP(instance.getDestinationIP()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withTargetPort(instance.getTargetPort()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule instance) {
    this(instance,false);
  }
  public L4RedirectRuleBuilder(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestinationIP(instance.getDestinationIP()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTargetPort(instance.getTargetPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRuleFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.L4RedirectRule build() {
    L4RedirectRule buildable = new L4RedirectRule(fluent.getDestinationIP(),fluent.getPort(),fluent.getProtocol(),fluent.getTargetPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    L4RedirectRuleBuilder that = (L4RedirectRuleBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class L4RedirectRuleBuilder extends L4RedirectRuleFluentImpl<L4RedirectRuleBuilder> implements VisitableBuilder<L4RedirectRule,L4RedirectRuleBuilder>{
  public L4RedirectRuleBuilder() {
    this(false);
  }
  public L4RedirectRuleBuilder(Boolean validationEnabled) {
    this(new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent) {
    this(fluent, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new L4RedirectRule(), validationEnabled);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance) {
    this(fluent, instance, false);
  }
  public L4RedirectRuleBuilder(L4RedirectRuleFluent<?> fluent,L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDestinationIP(instance.getDestinationIP()); 
    fluent.withPort(instance.getPort()); 
    fluent.withProtocol(instance.getProtocol()); 
    fluent.withTargetPort(instance.getTargetPort()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance) {
    this(instance,false);
  }
  public L4RedirectRuleBuilder(L4RedirectRule instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDestinationIP(instance.getDestinationIP()); 
    this.withPort(instance.getPort()); 
    this.withProtocol(instance.getProtocol()); 
    this.withTargetPort(instance.getTargetPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  L4RedirectRuleFluent<?> fluent;
  Boolean validationEnabled;
  public L4RedirectRule build() {
    L4RedirectRule buildable = new L4RedirectRule(fluent.getDestinationIP(),fluent.getPort(),fluent.getProtocol(),fluent.getTargetPort());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
